Module errors

Module errors 

Error types and utilities.

Structs

CharToJavaError
Raised by char_to_java and the implementation of TryFrom<char> for JValue / JValueOwned when a Rust char is not representable as a Java char.
Exception
LogContextErrorAndDefault
An error policy that logs errors and panics along with a context string before returning a default value.
LogErrorAndDefault
An error policy that logs errors and panics before returning a default value.
ThrowRuntimeExAndDefault
An error policy that throws java.lang.RuntimeException for any Rust error or panic, returning null or 0 as a default value.

Enums

Error
JniError
StartJvmError
An error that occurred while starting the JVM using the JNI Invocation API.

Traits

ErrorPolicy
A policy for handling EnvOutcome errors and panics that may occur within a native method.
ToException

Functions

jni_error_code_to_result

Type Aliases

Result
StartJvmResult