JObject

Struct JObject 

pub struct JObject<'local> { /* private fields */ }
A java.lang.Object reference, tied to a JNI local reference frame.

This is a #[repr(transparent)] wrapper around a jobject JNI reference.

Since it is #[repr(transparent)], it can be used to capture references passed to native methods while also associating them with a local reference frame lifetime for the method call.

Casting

Most other types in the objects module implement Into<JObject> or AsRef<JObject> to allow easy upcasting to JObject.

For downcasting (i.e converting to a more specific type), with runtime checks, use one of these APIs:

or look for a cast_local API like JString::cast_local.

Local Reference Frame Lifetime

The lifetime 'local represents the local reference frame that this reference belongs to. See the Env documentation for more information about local reference frames.

The lifetime may be 'static if the reference has a Global or Weak wrapper that indicates that the reference is global or weak (i.e it does not belong to a local reference frame).

Note that an owned JObject is always a local reference and will never have the 'static lifetime. Global does implement AsRef<JObject<’static>>, but this only yields a borrowed &JObject<'static>, never an owned JObject<'static>.

Local references belong to a single thread and are not safe to share across threads. This type implements Send and Sync if and only if the lifetime 'local is 'static.

Implementations

Source

impl JObject<'_>

pub unsafe fn from_raw<'local>( _env: &Env<'local>, raw: jobject, ) -> JObject<'local>

Creates a JObject that wraps the given raw jobject

Safety
  • raw must be a valid raw JNI local reference (or null).
  • There must not be any other owning Reference wrapper for the same reference.
  • The local reference must belong to the current thread and not outlive the JNI stack frame associated with the Env 'local lifetime.
pub const fn null() -> JObject<'static>

Creates a new null reference.

Null references are always valid and do not belong to a local reference frame. Therefore, the returned JObject always has the 'static lifetime.

pub const fn as_raw(&self) -> jobject

Returns the raw JNI pointer.

pub const fn into_raw(self) -> jobject

Unwrap to the internal jni type.