JSet

Struct JSet 

pub struct JSet<'local>(/* private fields */);
A java.util.Set reference, tied to a JNI local reference frame.

See the JObject documentation for more information about object references, how to cast them, and local reference frame lifetimes.

Implementations

Source

impl<'local> JSet<'local>

pub unsafe fn from_raw<'env_inner>( env: &Env<'env_inner>, raw: jobject, ) -> JSet<'env_inner>

Creates a JSet that wraps the given raw jobject

Safety
  • raw must be a valid raw JNI local reference (or null).
  • raw must be an instance of the correct Java class.
  • There must not be any other owning Reference wrapper for the same reference.
  • The local reference must belong to the current thread and not outlive the JNI stack frame associated with the Env 'local lifetime.
pub const fn null() -> JSet<'static>

Creates a new null reference.

Null references are always valid and do not belong to a local reference frame. Therefore, the returned JSet always has the 'static lifetime.

pub fn into_raw(self) -> jobject

Unwrap to the raw jni type.

pub fn cast_local<'any_local>( env: &mut Env<'_>, obj: impl Reference + Into<JObject<'any_local>> + AsRef<JObject<'any_local>>, ) -> Result<JSet<'any_local>>

Cast a local reference to a JSet

This will do a runtime (IsInstanceOf) check that the object is an instance of the correct class.

Also see these other options for casting local or global references to a JSet:

Errors

Returns Error::WrongObjectType if the IsInstanceOf check fails.

Source

impl<'local> JSet<'local>

pub fn as_collection(&self) -> Cast<'local, '_, JCollection<'local>>

Casts this JSet to a ::jni::objects::JCollection

This does not require a runtime type check since any JSet is also a ::jni::objects::JCollection

Source

impl<'local> JSet<'local>

pub fn add<'any_local>( &self, env: &mut Env<'_>, element: impl AsRef<JObject<'any_local>>, ) -> Result<bool>

Adds the given element to this set if it is not already present

Returns true if the element was added, false if it was already present.

Throws
  • UnsupportedOperationException - if the add operation is not supported
  • ClassCastException - if the element type isn’t compatible with the set
  • NullPointerException - if the given element is null and the set does not allow null values
  • IllegalArgumentException - if the element has a property that prevents it from being added to this set
pub fn remove<'any_local>( &self, env: &mut Env<'_>, element: impl AsRef<JObject<'any_local>>, ) -> Result<bool>

Removes the given element from this set if it is present

Returns true if the element was removed.

Throws
  • UnsupportedOperationException - if the remove operation is not supported
  • ClassCastException - if the element type isn’t compatible with the set
  • NullPointerException - if the given element is null and the set does not allow null values
pub fn clear(&self, env: &mut Env<'_>) -> Result<()>

Removes all of the elements from this set.

Throws
  • UnsupportedOperationException - if the clear operation is not supported
pub fn contains(&self, env: &mut Env<'_>, element: &JObject<'_>) -> Result<bool>

Checks if the given element is present in this set.

Returns true if the element is present, false otherwise.

Throws
  • ClassCastException - if the element type isn’t compatible with the set
  • NullPointerException - if the given element is null and the set does not allow null values
pub fn size(&self, env: &mut Env<'_>) -> Result<i32>

Returns the number of elements in this set.

pub fn is_empty(&self, env: &mut Env<'_>) -> Result<bool>

Returns true if this set contains no elements.

pub fn iterator<'env_local>( &self, env: &mut Env<'env_local>, ) -> Result<JIterator<'env_local>>

Returns an iterator (java.util.Iterator) over the elements in this set.

Methods from Deref<Target = JObject<'local>>

pub fn as_raw(&self) -> jobject

Returns the raw JNI pointer.