Error types and utilities.
Structs
- Char
ToJava Error - Raised by
char_to_javaand the implementation ofTryFrom<char>forJValue/JValueOwnedwhen a Rustcharis not representable as a Javachar. - Exception
- LogContext
Error AndDefault - An error policy that logs errors and panics along with a context string before returning a default value.
- LogError
AndDefault - An error policy that logs errors and panics before returning a default value.
- Throw
Runtime ExAnd Default - An error policy that throws
java.lang.RuntimeExceptionfor any Rust error or panic, returningnullor0as a default value.
Enums
- Error
- JniError
- Start
JvmError - An error that occurred while starting the JVM using the JNI Invocation API.
Traits
- Error
Policy - A policy for handling
EnvOutcomeerrors and panics that may occur within a native method. - ToException