pub struct JExceptionInInitializerError<'local>(/* private fields */);Expand description
A java.lang.ExceptionInInitializerError reference, tied to a JNI local reference frame.
See the JObject documentation for more information about object references,
how to cast them, and local reference frame lifetimes.
Implementations
Sourceimpl<'local> JExceptionInInitializerError<'local>
impl<'local> JExceptionInInitializerError<'local>
Sourcepub unsafe fn from_raw<'env_inner>(
env: &Env<'env_inner>,
raw: jobject,
) -> JExceptionInInitializerError<'env_inner>
pub unsafe fn from_raw<'env_inner>( env: &Env<'env_inner>, raw: jobject, ) -> JExceptionInInitializerError<'env_inner>
Creates a JExceptionInInitializerError that wraps the given raw jobject
Safety
rawmust be a valid raw JNI local reference (ornull).rawmust be an instance of the correct Java class.- There must not be any other owning Reference wrapper for the same reference.
- The local reference must belong to the current thread and not outlive the
JNI stack frame associated with the Env
'locallifetime.
Sourcepub const fn null() -> JExceptionInInitializerError<'static>
pub const fn null() -> JExceptionInInitializerError<'static>
Creates a new null reference.
Null references are always valid and do not belong to a local reference frame. Therefore,
the returned JExceptionInInitializerError always has the 'static lifetime.
Sourcepub fn cast_local<'any_local>(
env: &mut Env<'_>,
obj: impl Reference + Into<JObject<'any_local>> + AsRef<JObject<'any_local>>,
) -> Result<JExceptionInInitializerError<'any_local>>
pub fn cast_local<'any_local>( env: &mut Env<'_>, obj: impl Reference + Into<JObject<'any_local>> + AsRef<JObject<'any_local>>, ) -> Result<JExceptionInInitializerError<'any_local>>
Cast a local reference to a JExceptionInInitializerError
This will do a runtime (IsInstanceOf) check that the object is an instance of the correct class.
Also see these other options for casting local or global references to a JExceptionInInitializerError:
Errors
Returns Error::WrongObjectType if the IsInstanceOf check fails.
Sourceimpl<'local> JExceptionInInitializerError<'local>
impl<'local> JExceptionInInitializerError<'local>
Sourcepub fn as_throwable(&self) -> Cast<'local, '_, JThrowable<'local>>
pub fn as_throwable(&self) -> Cast<'local, '_, JThrowable<'local>>
Casts this JExceptionInInitializerError to a ::jni::objects::JThrowable
This does not require a runtime type check since any JExceptionInInitializerError is also a ::jni::objects::JThrowable
Sourceimpl JExceptionInInitializerError<'static>
impl JExceptionInInitializerError<'static>
Sourcepub fn new_null<'env_local>(
env: &mut Env<'env_local>,
) -> Result<JExceptionInInitializerError<'env_local>>
pub fn new_null<'env_local>( env: &mut Env<'env_local>, ) -> Result<JExceptionInInitializerError<'env_local>>
Construct without any message
Sourcepub fn new<'env_local, 'local_0>(
env: &mut Env<'env_local>,
msg: impl AsRef<JString<'local_0>>,
) -> Result<JExceptionInInitializerError<'env_local>>
pub fn new<'env_local, 'local_0>( env: &mut Env<'env_local>, msg: impl AsRef<JString<'local_0>>, ) -> Result<JExceptionInInitializerError<'env_local>>
Construct with a message
Sourcepub fn new_with_exception<'env_local, 'local_0>(
env: &mut Env<'env_local>,
cause: impl AsRef<JThrowable<'local_0>>,
) -> Result<JExceptionInInitializerError<'env_local>>
pub fn new_with_exception<'env_local, 'local_0>( env: &mut Env<'env_local>, cause: impl AsRef<JThrowable<'local_0>>, ) -> Result<JExceptionInInitializerError<'env_local>>
Construct with only an exception cause and a null message
Sourceimpl<'local> JExceptionInInitializerError<'local>
impl<'local> JExceptionInInitializerError<'local>
Sourcepub fn get_cause<'env_local>(
&self,
env: &mut Env<'env_local>,
) -> Result<JThrowable<'env_local>>
pub fn get_cause<'env_local>( &self, env: &mut Env<'env_local>, ) -> Result<JThrowable<'env_local>>
Returns the exception that was thrown during static initialization.
Sourcepub fn get_exception<'env_local>(
&self,
env: &mut Env<'env_local>,
) -> Result<JThrowable<'env_local>>
pub fn get_exception<'env_local>( &self, env: &mut Env<'env_local>, ) -> Result<JThrowable<'env_local>>
Returns the exception that was thrown during static initialization.
Sourceimpl<'local> JExceptionInInitializerError<'local>
impl<'local> JExceptionInInitializerError<'local>
Sourcepub fn matches<'any, 'from>(
env: &Env<'_>,
throwable: &'from JThrowable<'any>,
) -> Result<Option<Cast<'any, 'from, JExceptionInInitializerError<'any>>>>
pub fn matches<'any, 'from>( env: &Env<'_>, throwable: &'from JThrowable<'any>, ) -> Result<Option<Cast<'any, 'from, JExceptionInInitializerError<'any>>>>
Checks if the given throwable is an instance of this exception type.
Returns Some(Cast<JExceptionInInitializerError>) if the throwable is an instance of this exception type
or returns None if it is not.
Returns Error::NullPtr if the throwable is null.