pub struct JSet<'local>(/* private fields */);Expand description
A java.util.Set reference, tied to a JNI local reference frame.
See the JObject documentation for more information about object references,
how to cast them, and local reference frame lifetimes.
Implementations
Sourceimpl<'local> JSet<'local>
impl<'local> JSet<'local>
Sourcepub unsafe fn from_raw<'env_inner>(
env: &Env<'env_inner>,
raw: jobject,
) -> JSet<'env_inner>
pub unsafe fn from_raw<'env_inner>( env: &Env<'env_inner>, raw: jobject, ) -> JSet<'env_inner>
Creates a JSet that wraps the given raw jobject
Safety
rawmust be a valid raw JNI local reference (ornull).rawmust be an instance of the correct Java class.- There must not be any other owning Reference wrapper for the same reference.
- The local reference must belong to the current thread and not outlive the
JNI stack frame associated with the Env
'locallifetime.
Sourcepub const fn null() -> JSet<'static>
pub const fn null() -> JSet<'static>
Creates a new null reference.
Null references are always valid and do not belong to a local reference frame. Therefore,
the returned JSet always has the 'static lifetime.
Sourcepub fn cast_local<'any_local>(
env: &mut Env<'_>,
obj: impl Reference + Into<JObject<'any_local>> + AsRef<JObject<'any_local>>,
) -> Result<JSet<'any_local>>
pub fn cast_local<'any_local>( env: &mut Env<'_>, obj: impl Reference + Into<JObject<'any_local>> + AsRef<JObject<'any_local>>, ) -> Result<JSet<'any_local>>
Cast a local reference to a JSet
This will do a runtime (IsInstanceOf) check that the object is an instance of the correct class.
Also see these other options for casting local or global references to a JSet:
Errors
Returns Error::WrongObjectType if the IsInstanceOf check fails.
Sourceimpl<'local> JSet<'local>
impl<'local> JSet<'local>
Sourcepub fn as_collection(&self) -> Cast<'local, '_, JCollection<'local>>
pub fn as_collection(&self) -> Cast<'local, '_, JCollection<'local>>
Casts this JSet to a ::jni::objects::JCollection
This does not require a runtime type check since any JSet is also a ::jni::objects::JCollection
Sourceimpl<'local> JSet<'local>
impl<'local> JSet<'local>
Sourcepub fn add<'any_local>(
&self,
env: &mut Env<'_>,
element: impl AsRef<JObject<'any_local>>,
) -> Result<bool>
pub fn add<'any_local>( &self, env: &mut Env<'_>, element: impl AsRef<JObject<'any_local>>, ) -> Result<bool>
Adds the given element to this set if it is not already present
Returns true if the element was added, false if it was already present.
Throws
UnsupportedOperationException- if the add operation is not supportedClassCastException- if the element type isn’t compatible with the setNullPointerException- if the given element is null and the set does not allow null valuesIllegalArgumentException- if the element has a property that prevents it from being added to this set
Sourcepub fn remove<'any_local>(
&self,
env: &mut Env<'_>,
element: impl AsRef<JObject<'any_local>>,
) -> Result<bool>
pub fn remove<'any_local>( &self, env: &mut Env<'_>, element: impl AsRef<JObject<'any_local>>, ) -> Result<bool>
Removes the given element from this set if it is present
Returns true if the element was removed.
Throws
UnsupportedOperationException- if the remove operation is not supportedClassCastException- if the element type isn’t compatible with the setNullPointerException- if the given element is null and the set does not allow null values
Sourcepub fn clear(&self, env: &mut Env<'_>) -> Result<()>
pub fn clear(&self, env: &mut Env<'_>) -> Result<()>
Removes all of the elements from this set.
Throws
UnsupportedOperationException- if the clear operation is not supported
Sourcepub fn contains(&self, env: &mut Env<'_>, element: &JObject<'_>) -> Result<bool>
pub fn contains(&self, env: &mut Env<'_>, element: &JObject<'_>) -> Result<bool>
Checks if the given element is present in this set.
Returns true if the element is present, false otherwise.
Throws
ClassCastException- if the element type isn’t compatible with the setNullPointerException- if the given element is null and the set does not allow null values
Sourcepub fn size(&self, env: &mut Env<'_>) -> Result<i32>
pub fn size(&self, env: &mut Env<'_>) -> Result<i32>
Returns the number of elements in this set.